@@ -44,14 +44,6 @@ class Dispatcher(IScoped):
         handler = self.find_handler(cq, handler_type)
         if handler is None:
             raise Exception("Handler not founded")
-        try:
-            result = handler.handle(cq)
-            self.service_provider.get(RepositoryProvider).commit()
-            if isinstance(cq, IQuery):
-                return result
-        except Exception as ex:
-            self.service_provider.get(RepositoryProvider).rollback()
-            self.service_provider.get(SqlLogger).exception(ex, str(ex))
-            raise
-        finally:
-            self.service_provider.get(RepositoryProvider).close()
+        result = handler.handle(cq)
+        if isinstance(cq, IQuery):
+            return result
