@@ -1,6 +1,6 @@
 from abc import abstractmethod
 
-from pdip.dependency import IScoped
+from ......dependency import IScoped
 
 
 class BigDataConnector(IScoped):
@@ -45,7 +45,3 @@ class BigDataConnector(IScoped):
     @abstractmethod
     def get_table_data_with_paging_query(self, query, start, end):
         return f"SELECT * FROM ({query}) ordered_query   order by null limit {end - start} offset {start}"
-
-    @abstractmethod
-    def prepare_data(self, data):
-        return data
