@@ -2,9 +2,25 @@ from typing import List
 
 from dataclasses import dataclass
 
-from ....connection.domain.enums import ConnectionTypes
 from ....connection.domain.bigdata import BigDataConnectionConfiguration
+from ....connection.domain.enums import ConnectionTypes
+from ....connection.domain.inmemory import InMemoryConnectionConfiguration
 from ....connection.domain.sql import SqlConnectionConfiguration
+from ....connection.domain.webservice.base import WebServiceConnectionConfiguration
+
+
+@dataclass
+class IntegrationConnectionInMemoryDataBase:
+    Connection: InMemoryConnectionConfiguration = None
+    Schema: str = None
+    ObjectName: str = None
+    Query: str = None
+
+@dataclass
+class IntegrationConnectionWebServiceBase:
+    Connection: WebServiceConnectionConfiguration = None
+    Method: str = None
+    RequestBody: str = None
 
 
 @dataclass
@@ -32,9 +48,13 @@ class IntegrationConnectionColumnBase:
 @dataclass
 class IntegrationConnectionBase:
     ConnectionName: str = None
-    ConnectionType: ConnectionTypes=None
+    ConnectionType: ConnectionTypes = None
     Sql: IntegrationConnectionSqlBase = None
     BigData: IntegrationConnectionBigDataBase = None
+    WebService: IntegrationConnectionWebServiceBase = None
+    WebService: IntegrationConnectionWebServiceBase = None
+    File: any = None
+    Queue: any = None
     Columns: List[IntegrationConnectionColumnBase] = None
 
 
