@@ -1,10 +1,10 @@
 from injector import inject
 
-from pdip.integrator.base import Initializer
-from pdip.integrator.operation.domain import OperationBase
+from ..domain import OperationBase
+from ...base import Initializer
 
 
 class OperationInitializer(Initializer):
     @inject
     def initialize(self, operation: OperationBase) -> int:
-        pass
\ No newline at end of file
+        pass
