@@ -2,18 +2,20 @@ from injector import inject
 
 from .operation_initializer import OperationInitializer
 from ....dependency import IScoped
-from ....dependency.container import DependencyContainer
+from ....dependency.provider import ServiceProvider
 
 
 class OperationInitializerFactory(IScoped):
     @inject
-    def __init__(self
-                 ):
-        pass
+    def __init__(
+            self,
+            service_provider: ServiceProvider
+    ):
+        self.service_provider = service_provider
 
     def get_initializer(self) -> OperationInitializer:
         subclasses = OperationInitializer.__subclasses__()
         if subclasses is not None and len(subclasses) > 0:
             initializer_class = subclasses[0]
-            initializer = DependencyContainer.Instance.get(initializer_class)
+            initializer = self.service_provider.get(initializer_class)
             return initializer
